/*

Copyright (C) 2001  Gopal Narayanan <gopal@astro.umass.edu>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

*/

/* body.h
 * added c_microstrip_win(), C.G.
 */

#ifndef __BODY_H
#define __BODY_H

#include "transcalc.h"

/*GtkWidget *setup_body (GtkWidget *);*/
GtkWidget *setup_body (trans_gui *);
/*void transtype (gpointer); */
void transtype (GtkWidget *, gpointer);
short transtype_int (void);

/*extern trans_win *microstrip_win (GtkWidget *);*/
extern trans_win *microstrip_win (trans_gui *);
extern trans_win *rectwaveguide_win (trans_gui *);
extern trans_win *coax_win (trans_gui *);
extern trans_win *c_microstrip_win (trans_gui *);

#endif

